==> dateparser_0.7.1.orig.tar.gz: dateparser-0.7.1/dateparser/data/date_translation_data/uz.py <==
# -*- coding: utf-8 -*-
info = {
    "name": "uz",
    "date_order": "DMY",
    "january": [
        "yanvar",
        "yan"
    ],
    "february": [
        "fevral",
        "fev"
    ],
    "march": [
        "mart",
        "mar"
    ],
    "april": [
        "aprel",
        "apr"
    ],
    "may": [
        "may"
    ],
    "june": [
        "iyun",
        "iyn"
    ],
    "july": [
        "iyul",
        "iyl"
    ],
    "august": [
        "avgust",
        "avg"
    ],
    "september": [
        "sentabr",
        "sen"
    ],
    "october": [
        "oktabr",
        "okt"
    ],
    "november": [
        "noyabr",
        "noy"
    ],
    "december": [
        "dekabr",
        "dek"
    ],
    "monday": [
        "dushanba",
        "dush"
    ],
    "tuesday": [
        "seshanba",
        "sesh"
    ],
    "wednesday": [
        "chorshanba",
        "chor"
    ],
    "thursday": [
        "payshanba",
        "pay"
    ],
    "friday": [
        "juma",
        "jum"
    ],
    "saturday": [
        "shanba",
        "shan"
    ],
    "sunday": [
        "yakshanba",
        "yak"
    ],
    "am": [
        "to"
    ],
    "pm": [
        "tk"
    ],
    "year": [
        "yil"
    ],
    "month": [
        "oy"
    ],
    "week": [
        "hafta"
    ],
    "day": [
        "kun"
    ],
    "hour": [
        "soat"
    ],
    "minute": [
        "daqiqa",
        "daq"
    ],
    "second": [
        "soniya",
        "son"
    ],
    "relative-type": {
        "1 year ago": [
            "o‘tgan yil",
            "o'tgan yil"
        ],
        "0 year ago": [
            "shu yil",
            "bu yil"
        ],
        "in 1 year": [
            "keyingi yil"
        ],
        "1 month ago": [
            "o‘tgan oy"
        ],
        "0 month ago": [
            "shu oy"
        ],
        "in 1 month": [
            "keyingi oy"
        ],
        "1 week ago": [
            "o‘tgan hafta"
        ],
        "0 week ago": [
            "shu hafta"
        ],
        "in 1 week": [
            "keyingi hafta"
        ],
        "1 day ago": [
            "kecha"
        ],
        "0 day ago": [
            "bugun"
        ],
        "in 1 day": [
            "ertaga"
        ],
        "0 hour ago": [
            "shu soatda"
        ],
        "0 minute ago": [
            "shu daqiqada"
        ],
        "0 second ago": [
            "hozir"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) yildan keyin"
        ],
        "\\1 year ago": [
            "(\\d+) yil oldin"
        ],
        "in \\1 month": [
            "(\\d+) oydan keyin"
        ],
        "\\1 month ago": [
            "(\\d+) oy oldin"
        ],
        "in \\1 week": [
            "(\\d+) haftadan keyin"
        ],
        "\\1 week ago": [
            "(\\d+) hafta oldin"
        ],
        "in \\1 day": [
            "(\\d+) kundan keyin"
        ],
        "\\1 day ago": [
            "(\\d+) kun oldin"
        ],
        "in \\1 hour": [
            "(\\d+) soatdan keyin"
        ],
        "\\1 hour ago": [
            "(\\d+) soat oldin"
        ],
        "in \\1 minute": [
            "(\\d+) daqiqadan keyin"
        ],
        "\\1 minute ago": [
            "(\\d+) daqiqa oldin"
        ],
        "in \\1 second": [
            "(\\d+) soniyadan keyin"
        ],
        "\\1 second ago": [
            "(\\d+) soniya oldin"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}

==> dateparser_1.1.0.orig.tar.gz: dateparser-1.1.0/dateparser/data/date_translation_data/uz.py <==
info = {
    "name": "uz",
    "date_order": "DMY",
    "january": [
        "yan",
        "yanvar"
    ],
    "february": [
        "fev",
        "fevral"
    ],
    "march": [
        "mar",
        "mart"
    ],
    "april": [
        "apr",
        "aprel"
    ],
    "may": [
        "may"
    ],
    "june": [
        "iyn",
        "iyun"
    ],
    "july": [
        "iyl",
        "iyul"
    ],
    "august": [
        "avg",
        "avgust"
    ],
    "september": [
        "sen",
        "sentabr"
    ],
    "october": [
        "okt",
        "oktabr"
    ],
    "november": [
        "noy",
        "noyabr"
    ],
    "december": [
        "dek",
        "dekabr"
    ],
    "monday": [
        "dush",
        "dushanba"
    ],
    "tuesday": [
        "sesh",
        "seshanba"
    ],
    "wednesday": [
        "chor",
        "chorshanba"
    ],
    "thursday": [
        "pay",
        "payshanba"
    ],
    "friday": [
        "jum",
        "juma"
    ],
    "saturday": [
        "shan",
        "shanba"
    ],
    "sunday": [
        "yak",
        "yakshanba"
    ],
    "am": [
        "to"
    ],
    "pm": [
        "tk"
    ],
    "year": [
        "yil"
    ],
    "month": [
        "oy"
    ],
    "week": [
        "hafta"
    ],
    "day": [
        "kun"
    ],
    "hour": [
        "soat"
    ],
    "minute": [
        "daq",
        "daqiqa"
    ],
    "second": [
        "son",
        "soniya"
    ],
    "relative-type": {
        "0 day ago": [
            "bugun"
        ],
        "0 hour ago": [
            "shu soatda"
        ],
        "0 minute ago": [
            "shu daqiqada"
        ],
        "0 month ago": [
            "shu oy"
        ],
        "0 second ago": [
            "hozir"
        ],
        "0 week ago": [
            "shu hafta"
        ],
        "0 year ago": [
            "bu yil",
            "shu yil"
        ],
        "1 day ago": [
            "kecha"
        ],
        "1 month ago": [
            "o‘tgan oy"
        ],
        "1 week ago": [
            "o‘tgan hafta"
        ],
        "1 year ago": [
            "o'tgan yil",
            "o‘tgan yil"
        ],
        "in 1 day": [
            "ertaga"
        ],
        "in 1 month": [
            "keyingi oy"
        ],
        "in 1 week": [
            "keyingi hafta"
        ],
        "in 1 year": [
            "keyingi yil"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+) kun oldin"
        ],
        "\\1 hour ago": [
            "(\\d+) soat oldin"
        ],
        "\\1 minute ago": [
            "(\\d+) daqiqa oldin"
        ],
        "\\1 month ago": [
            "(\\d+) oy oldin"
        ],
        "\\1 second ago": [
            "(\\d+) soniya oldin"
        ],
        "\\1 week ago": [
            "(\\d+) hafta oldin"
        ],
        "\\1 year ago": [
            "(\\d+) yil oldin"
        ],
        "in \\1 day": [
            "(\\d+) kundan keyin"
        ],
        "in \\1 hour": [
            "(\\d+) soatdan keyin"
        ],
        "in \\1 minute": [
            "(\\d+) daqiqadan keyin"
        ],
        "in \\1 month": [
            "(\\d+) oydan keyin"
        ],
        "in \\1 second": [
            "(\\d+) soniyadan keyin"
        ],
        "in \\1 week": [
            "(\\d+) haftadan keyin"
        ],
        "in \\1 year": [
            "(\\d+) yildan keyin"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
